@@ -1,6 +1,7 @@
 package manager
 
 import (
+	"github.com/aws/aws-sdk-go/service/autoscaling"
 	"github.com/aws/aws-sdk-go/service/cloudformation"
 	"github.com/aws/aws-sdk-go/service/cloudtrail"
 	"github.com/aws/aws-sdk-go/service/eks/eksiface"
@@ -30,6 +31,8 @@ type GetNodegroupOption struct {
 	NodeGroupName string
 }
 
+var _ StackManager = &StackCollection{}
+
 //go:generate go run github.com/maxbrunsfeld/counterfeiter/v6 -generate
 //counterfeiter:generate -o fakes/fake_stack_manager.go . StackManager
 type StackManager interface {
@@ -52,6 +55,7 @@ type StackManager interface {
 	DoWaitUntilStackIsCreated(i *Stack) error
 	EnsureMapPublicIPOnLaunchEnabled() error
 	FixClusterCompatibility() error
+	GetAutoScalingGroupDesiredCapacity(name string) (autoscaling.Group, error)
 	GetAutoScalingGroupName(s *Stack) (string, error)
 	GetClusterStackIfExists() (*Stack, error)
 	GetFargateStack() (*Stack, error)
@@ -63,8 +67,8 @@ type StackManager interface {
 	GetNodeGroupName(s *Stack) string
 	GetNodeGroupStackType(options GetNodegroupOption) (v1alpha5.NodeGroupType, error)
 	GetStackTemplate(stackName string) (string, error)
-	GetUnmanagedNodeGroupSummaries(name string) ([]*NodeGroupSummary, error)
-	HasClusterStackUsingCachedList(clusterStackNames []string, clusterName string) (bool, error)
+	GetUnmanagedNodeGroupAutoScalingGroupName(s *Stack) (string, error)
+	HasClusterStackFromList(clusterStackNames []string, clusterName string) (bool, error)
 	ListClusterStackNames() ([]string, error)
 	ListIAMServiceAccountStacks() ([]string, error)
 	ListNodeGroupStacks() ([]NodeGroupStack, error)
